# -*- coding: utf-8 -*-
'''
lucterios.contacts package
@author: Laurent GAY
@organization: sd-libre.fr
@contact: info@sd-libre.fr
@copyright: 2017 sd-libre.fr
@license: This file is part of Lucterios.

Lucterios is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.
Lucterios is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.
You should have received a copy of the GNU General Public License
along with Lucterios.  If not, see <http://www.gnu.org/licenses/>.
'''
from __future__ import unicode_literals
import re


from diacamma.accounting.system.default import DefaultSystemAccounting

GENERAL_MASK = r'^[0-8][0-9][0-9a-zA-Z]*$'

CASH_MASK = r'^5[0-9][0-9][0-9a-zA-Z]*$'

CASH_MASK_BEGIN = '5'

PROVIDER_MASK = r'^44[0-9][0-9a-zA-Z]*$'

CUSTOMER_MASK = r'^40[0-9][0-9a-zA-Z]*$'

EMPLOYED_MASK = r'^455[0-9][0-9a-zA-Z]*$'

SOCIETARY_MASK = r'^47[0-9][0-9a-zA-Z]*$|^410[0-9a-zA-Z]*$'

REVENUE_MASK = r'^7[0-9][0-9][0-9a-zA-Z]*$'

EXPENSE_MASK = r'^6[0-9][0-9][0-9a-zA-Z]*$'

THIRD_MASK = "%s|%s|%s|%s" % (PROVIDER_MASK, CUSTOMER_MASK, EMPLOYED_MASK, SOCIETARY_MASK)

GENERAL_CHARTS_ACCOUNT = [
    ("000", "Créanciers, bénéficiaires de garanties de tiers", 5),
    ("001", "Tiers constituants de garanties pour compte de l'entreprise", 5),
    ("010", "Débiteurs pour engagements sur effets", 5),
    ("011", "Créanciers d'engagements sur effets", 5),
    ("0110", "Effets cédés par l'entreprise sous endos", 5),
    ("0111", "Autres engagements sur effets en circulation", 5),
    ("012", "Débiteurs pour autres garanties personnelles", 5),
    ("013", "Créanciers d'autres garanties personnelles", 5),
    ("020", "Créanciers de l'entreprise, bénéficiaires de garanties réelles", 5),
    ("021", "Garanties réelles constituées pour compte propre", 5),
    ("022", "Créanciers de tiers, bénéficiaires de garanties réelles", 5),
    ("023", "Garanties réelles constituées pour compte de tiers", 5),
    ("030", "Dépôts statutaires", 5),
    ("031", "Déposants statutaires", 5),
    ("032", "Garanties reçues", 5),
    ("033", "Constituants de garanties", 5),
    ("040", "Tiers, détenteurs en leur nom mais aux risques et profits de l'entreprise de biens et de valeurs", 5),
    ("041", "Biens et valeurs détenus par des tiers en leur nom mais aux risques et profits de l'entreprise", 5),
    ("050", "Engagements d'acquisition", 5),
    ("051", "Créanciers d'engagements d'acquisition", 5),
    ("052", "Débiteurs pour engagements de cession", 5),
    ("053", "Engagements de cession", 5),
    ("060", "Marchandises achetées à terme - à recevoir", 5),
    ("061", "Créanciers pour marchandises achetées à terme", 5),
    ("062", "Débiteurs pour marchandises vendues à terme - à livrer", 5),
    ("063", "Marchandises vendues à terme - à livrer", 5),
    ("064", "Devises achetées à terme - à recevoir", 5),
    ("065", "Créanciers pour devises achetées à terme", 5),
    ("066", "Débiteurs pour devises vendues à terme", 5),
    ("067", "Devises vendues à terme - à livrer", 5),
    ("070", "Droits d'usage à long terme", 5),
    ("0700", "Sur terrains et constructions", 5),
    ("0701", "Sur installations, machines et outillage", 5),
    ("0702", "Sur mobilier et matériel roulant", 5),
    ("071", "Créanciers de loyers et redevances", 5),
    ("072", "Biens et valeurs de tiers reçus en dépôt, en consignation, ou à façon", 5),
    ("073", "Commettants et déposants de biens et valeurs", 5),
    ("074", "Biens et valeurs détenus pour compte ou aux risques et profits de tiers", 5),
    ("075", "Créanciers de biens et valeurs détenus pour compte de tiers ou à leurs risques et profits", 5),
    ("09", "DROITS ET ENGAGEMENTS DIVERS", 5),
    ("100", "Capital souscrit ou capital personnel", 2),
    ("1000", "Capital non amorti", 2),
    ("1001", "Capital amorti", 2),
    ("101", "Capital non appelé", 2),
    ("109", "Compte de l'exploitant", 2),
    ("1090", "Opérations courantes", 2),
    ("1091", "Impôts personnels", 2),
    ("1092", "Rémunérations et autres avantages", 2),
    ("11", "PRIMES D'EMISSION", 2),
    ("120", "Plus-values de réévaluation sur immobilisations incorporelles", 2),
    ("1200", "Plus-values de réévaluation", 2),
    ("1201", "Reprises de réductions de valeur", 2),
    ("121", "Plus-values de réévaluation sur immobilisations corporelles", 2),
    ("1210", "Plus-values de réévaluation", 2),
    ("1211", "Reprises de réductions de valeur", 2),
    ("122", "Plus-values de réévaluation sur immobilisations financières", 2),
    ("1220", "Plus-values de réévaluation", 2),
    ("1221", "Reprises de réductions de valeur", 2),
    ("123", "Plus-values de réévaluation sur stocks", 2),
    ("124", "Reprises de réductions de valeur sur placements de trésorerie", 2),
    ("130", "Réserve légale", 2),
    ("131", "Réserves indisponibles", 2),
    ("1310", "Réserve pour actions propres", 2),
    ("1311", "Autres réserves indisponibles", 2),
    ("132", "Réserves immunisées", 2),
    ("133", "Réserves disponibles", 2),
    ("1330", "Réserve pour régularisation de dividendes", 2),
    ("1331", "Réserve pour renouvellement des immobilisations", 2),
    ("1332", "Réserve pour installations en faveur du personnel", 2),
    ("1333", "Réserves libres", 2),
    ("140", "Bénéfice reporté", 2),
    ("141", "Perte reportée", 2),
    ("150", "Montants obtenus", 2),
    ("151", "Montants transférés aux résultats", 2),
    ("16", "Provisions", 2),
    ("160", "Provisions pour pensions et obligations similaires", 2),
    ("161", "Provisions pour charges fiscales", 2),
    ("162", "Provisions pour grosses réparations et gros entretiens", 2),
    ("163", "Provisions pour autres risques et charges", 2),
    ("164", "Provisions pour sûretés personnelles ou réelles constituées à l'appui de dettes et d'engagements de tiers", 2),
    ("165", "Provisions pour engagements relatifs à l'acquisition ou à la cession d'immobilisations", 2),
    ("166", "Provisions pour exécution de commandes passées ou reçues", 2),
    ("167", "Provisions pour positions et marchés à terme en devises ou positions et marchés à terme en marchandises", 2),
    ("168", "Provisions pour garanties techniques attachées aux ventes et prestations déjà effectuées par l'entreprise", 2),
    ("169", "Provisions pour autres risques et charges", 2),
    ("1690", "Pour litiges en cours", 2),
    ("1691", "Pour amendes, doubles droits, pénalités", 2),
    ("1692", "Pour propre assureur", 2),
    ("1693", "Pour risques inhérents aux opérations de crédits à moyen ou long terme", 2),
    ("1695", "Provision pour charge de liquidation", 2),
    ("1696", "Provision pour départ de personnel", 2),
    ("1699", "Pour risques divers", 2),
    ("170", "Emprunts subordonnés", 2),
    ("1700", "Convertibles", 2),
    ("1701", "Non convertibles", 2),
    ("171", "Emprunts obligataires non subordonnés", 2),
    ("1710", "Convertibles", 2),
    ("1711", "Non convertibles", 2),
    ("172", "Dettes de location-financement et assimilés", 2),
    ("1720", "Dettes de location-financement de biens immobiliers", 2),
    ("1721", "Dettes de location-financement de biens mobiliers", 2),
    ("1722", "Dettes sur droits réels sur immeubles", 2),
    ("173", "Etablissements de crédit", 2),
    ("1730", "Dettes en compte", 2),
    ("1731", "Promesses", 2),
    ("1732", "Crédits d'acceptation", 2),
    ("174", "Autres emprunts", 2),
    ("175", "Dettes commerciales", 2),
    ("1750", "Fournisseurs : dettes en compte", 2),
    ("17500", "Entreprises apparentées", 2),
    ("175000", "Entreprises liées", 2),
    ("175001", "Entreprises avec lesquelles il existe un lien de participation", 2),
    ("17501", "Fournisseurs ordinaires", 2),
    ("175010", "Fournisseurs belges", 2),
    ("175011", "Fournisseurs C.E.E.", 2),
    ("175012", "Fournisseurs importation", 2),
    ("1751", "Effets à payer", 2),
    ("17510", "Entreprises apparentées", 2),
    ("175100", "Entreprises liées", 2),
    ("175101", "Entreprises avec lesquelles il existe un lien de participation", 2),
    ("17511", "Fournisseurs ordinaires", 2),
    ("175110", "Fournisseurs belges", 2),
    ("175111", "Fournisseurs C.E.E.", 2),
    ("175112", "Fournisseurs importation", 2),
    ("176", "Acomptes reçus sur commandes", 2),
    ("178", "Cautionnements reçus en numéraires", 2),
    ("179", "Dettes diverses", 2),
    ("1790", "Entreprises liées", 2),
    ("1791", "Autres entreprises avec lesquelles il existe un lien de participation", 2),
    ("1792", "Administrateurs, gérants, associés", 2),
    ("1794", "Rentes viagères capitalisées", 2),
    ("1798", "Dettes envers les coparticipants des associations momentanées et en participation", 2),
    ("1799", "Autres dettes diverses", 2),
    ("18", "COMPTES DE LIAISON DES ETABLISSEMENTS ET SUCCURSALES", 2),
    ("200", "Frais de constitution et d'augmentation de capital", 0),
    ("2000", "Frais de constitution et d'augmentation de capital", 0),
    ("2009", "Amortissements sur frais de constitution et d'augmentation de capital", 0),
    ("201", "Frais d'émission d'emprunts et primes de remboursement", 0),
    ("2010", "Agios sur emprunts et frais d'émission d'emprunts", 0),
    ("2019", "Amortissements sur agios sur emprunts et frais d'émission d'emprunts", 0),
    ("202", "Autres frais d'établissement", 0),
    ("2020", "Autres frais d'établissement", 0),
    ("2029", "Amortissements sur autres frais d'établissement", 0),
    ("203", "Intérêts intercalaires", 0),
    ("2030", "Intérêts intercalaires", 0),
    ("2039", "Amortissements sur intérêts intercalaires", 0),
    ("204", "Frais de restructuration", 0),
    ("2040", "Coût des frais de restructuration", 0),
    ("2049", "Amortissements sur frais de restructuration", 0),
    ("210", "Frais de recherche et de développement", 0),
    ("2100", "Frais de recherche et de mise au point", 0),
    ("2108", "Plus-values actées sur frais de recherche et de mise au point", 0),
    ("2109", "Amortissements sur frais de recherche et de mise au point", 0),
    ("211", "Concessions, brevets, licences, savoir-faire, marques et droits similaires", 0),
    ("2110", "Concessions, brevets, licences, savoir-faire, marques, etc...", 0),
    ("2118", "Plus-values actées sur concessions, brevets, etc...", 0),
    ("2119", "Amortissements sur concessions, brevets, etc...", 0),
    ("212", "Goodwill", 0),
    ("2120", "Coût d'acquisition", 0),
    ("2128", "Plus-values actées", 0),
    ("2129", "Amortissements sur goodwill", 0),
    ("213", "Acomptes versés", 0),
    ("220", "Terrains", 0),
    ("2200", "Terrains", 0),
    ("2201", "Frais d'acquisition sur terrains", 0),
    ("2208", "Plus-values actées sur terrains", 0),
    ("2209", "Amortissements et réductions de valeur", 0),
    ("22090", "Amortissements sur frais d'acquisition", 0),
    ("22091", "Réductions de valeur sur terrains", 0),
    ("221", "Constructions", 0),
    ("210", "Bâtiments industriels", 0),
    ("2211", "Bâtiments administratifs et commerciaux", 0),
    ("2212", "Autres bâtiments d'exploitation", 0),
    ("2213", "Voies de transport et ouvrages d'art", 0),
    ("2215", "Constructions sur sol d'autrui", 0),
    ("2216", "Frais d'acquisition sur constructions", 0),
    ("2218", "Plus-values actées", 0),
    ("22180", "Sur bâtiments industriels", 0),
    ("22181", "Sur bâtiments administratifs et commerciaux", 0),
    ("22182", "Sur autres bâtiments d'exploitation", 0),
    ("22184", "Sur voies de transport et ouvrages d'art", 0),
    ("2219", "Amortissements sur constructions", 0),
    ("22190", "Sur bâtiments industriels", 0),
    ("22191", "Sur bâtiments administratifs et commerciaux", 0),
    ("22192", "Sur autres bâtiments d'exploitation", 0),
    ("22194", "Sur voies de transport et ouvrages d'art", 0),
    ("22195", "Sur constructions sur sol d'autrui", 0),
    ("22196", "Sur frais d'acquisition sur constructions", 0),
    ("222", "Terrains bâtis", 0),
    ("2220", "Valeur d'acquisition", 0),
    ("22200", "Bâtiments industriels", 0),
    ("22201", "Bâtiments administratifs et commerciaux", 0),
    ("22202", "Autres bâtiments d'exploitation", 0),
    ("22203", "Voies de transport et ouvrages d'art", 0),
    ("22204", "Frais d'acquisition des terrains à bâtir", 0),
    ("2228", "Plus-values actées", 0),
    ("22280", "Sur bâtiments industriels", 0),
    ("22281", "Sur bâtiments administratifs et commerciaux", 0),
    ("22282", "Sur autres bâtiments d'exploitation", 0),
    ("22283", "Sur voies de transport et ouvrages d'art", 0),
    ("2229", "Amortissements sur terrains bâtis", 0),
    ("22290", "Sur bâtiments industriels", 0),
    ("22291", "Sur bâtiments administratifs et commerciaux", 0),
    ("22292", "Sur autres bâtiments d'exploitation", 0),
    ("22293", "Sur voies de transport et ouvrages d'art", 0),
    ("22294", "Sur frais d'acquisition des terrains bâtis", 0),
    ("223", "Autres droits réels sur des immeubles", 0),
    ("2230", "Valeur d'acquisition", 0),
    ("22238", "Plus-values actées", 0),
    ("2239", "Amortissements", 0),
    ("230", "Installations", 0),
    ("2300", "Installations bâtiments industriels", 0),
    ("2301", "Installations bâtiments administratifs et commerciaux", 0),
    ("2302", "Installations bâtiments d'exploitation", 0),
    ("2303", "Installations voies de transport et ouvrages d'art", 0),
    ("231", "Machines", 0),
    ("237", "Outillage", 0),
    ("238", "Plus-values actées", 0),
    ("2380", "Plus-values actées sur installations", 0),
    ("2381", "Plus-values actées sur machines", 0),
    ("2382", "Plus-values actées sur outillage", 0),
    ("239", "Amortissements actés", 0),
    ("2390", "Amortissements actés sur installations", 0),
    ("2391", "Amortissements actés sur machines", 0),
    ("2392", "Amortissements actés sur outillage", 0),
    ("2400", "Mobilier", 0),
    ("24000", "Mobilier des bâtiments industriels", 0),
    ("24001", "Mobilier des bâtiments administratifs et commerciaux", 0),
    ("24002", "Mobilier des autres bâtiments d'exploitation", 0),
    ("24003", "Mobilier oeuvres sociales", 0),
    ("2401", "Matériel de bureau et de service social", 0),
    ("24010", "Des bâtiments industriels", 0),
    ("24011", "Des bâtiments administratifs et commerciaux", 0),
    ("24012", "Des autres bâtiments d'exploitation", 0),
    ("24013", "Des oeuvres sociales", 0),
    ("2408", "Plus-values actées", 0),
    ("24080", "Plus-values actées sur mobilier", 0),
    ("24081", "Plus-values actées sur matériel de bureau et service social", 0),
    ("2409", "Amortissements", 0),
    ("24090", "Amortissements sur mobilier", 0),
    ("24091", "Amortissements sur matériel de bureau et service social", 0),
    ("2410", "Matériel automobile", 0),
    ("24100", "Voitures", 0),
    ("24105", "Camions", 0),
    ("2411", "Matériel ferroviaire", 0),
    ("2412", "Matériel fluvial", 0),
    ("2413", "Matériel naval", 0),
    ("2414", "Matériel aérien", 0),
    ("2418", "Plus-values sur matériel roulant", 0),
    ("24180", "Plus-values sur matériel automobile", 0),
    ("24181", "Plus-values sur matériel ferroviaire", 0),
    ("24182", "Plus-values sur matériel fluvial", 0),
    ("24183", "Plus-values sur matériel naval", 0),
    ("24184", "Plus-values sur matériel aérien", 0),
    ("2419", "Amortissements sur matériel roulant", 0),
    ("24190", "Amortissements sur matériel automobile", 0),
    ("24191", "Amortissements sur matériel ferroviaire", 0),
    ("24192", "Amortissements sur matériel fluvial", 0),
    ("24193", "Amortissements sur matériel naval", 0),
    ("24194", "Amortissements sur matériel aérien", 0),
    ("250", "Terrains et constructions", 0),
    ("2500", "Terrains", 0),
    ("2501", "Constructions", 0),
    ("2508", "Plus-values sur emphytéose, leasing et droits similaires : terrains et constructions", 0),
    ("2509", "Amortissements et réductions de valeur sur terrains et constructions en leasing", 0),
    ("251", "Installations, machines et outillage", 0),
    ("2510", "Installations", 0),
    ("2511", "Machines", 0),
    ("2512", "Outillage", 0),
    ("2518", "Plus-values actées sur installations, machines et outillage pris en leasing", 0),
    ("2519", "Amortissements sur installations, machines et outillage pris en leasing", 0),
    ("252", "Mobilier et matériel roulant", 0),
    ("2520", "Mobilier", 0),
    ("2521", "Matériel roulant", 0),
    ("2528", "Plus-values actées sur mobilier et matériel roulant en leasing", 0),
    ("2529", "Amortissements sur mobilier et matériel roulant en leasing", 0),
    ("260", "Frais d'aménagements de locaux pris en location", 0),
    ("261", "Maison d'habitation", 0),
    ("262", "Réserve immobilière", 0),
    ("263", "Matériel d'emballage", 0),
    ("264", "Emballages récupérables", 0),
    ("268", "Plus-values actées sur autres immobilisations corporelles", 0),
    ("269", "Amortissements sur autres immobilisations corporelles", 0),
    ("2690", "Amortissements sur frais d'aménagement des locaux pris en location", 0),
    ("2691", "Amortissements sur maison d'habitation", 0),
    ("2692", "Amortissements sur réserve immobilière", 0),
    ("2693", "Amortissements sur matériel d'emballage", 0),
    ("2694", "Amortissements sur emballages récupérables", 0),
    ("270", "Immobilisations en cours", 0),
    ("2700", "Constructions", 0),
    ("2701", "Installations, machines et outillage", 0),
    ("2702", "Mobilier et matériel roulant", 0),
    ("2703", "Autres immobilisations corporelles", 0),
    ("271", "Avances et acomptes versés sur immobilisations en cours", 0),
    ("280", "Participations dans des entreprises liées", 0),
    ("2800", "Valeur d'acquisition (peut être subdivisé par participation)", 0),
    ("2801", "Montants non appelés (idem)", 0),
    ("2808", "Plus-values actées (idem)", 0),
    ("2809", "Réductions de valeurs actées (idem)", 0),
    ("281", "Créances sur des entreprises liées", 0),
    ("2810", "Créances en compte", 0),
    ("2811", "Effets à recevoir", 0),
    ("2812", "Titres à revenu fixes", 0),
    ("2817", "Créances douteuses", 0),
    ("2819", "Réductions de valeurs actées", 0),
    ("282", "Participations dans des entreprises avec lesquelles il existe un lien de participation", 0),
    ("2820", "Valeur d'acquisition (peut être subdivisé par participation)", 0),
    ("2821", "Montants non appelés (idem)", 0),
    ("2828", "Plus-values actées (idem)", 0),
    ("2829", "Réductions de valeurs actées (idem)", 0),
    ("283", "Créances sur des entreprises avec lesquelles il existe un lien de participation", 0),
    ("2830", "Créances en compte", 0),
    ("2831", "Effets à recevoir", 0),
    ("2832", "Titres à revenu fixe", 0),
    ("2837", "Créances douteuses", 0),
    ("2839", "Réductions de valeurs actées", 0),
    ("284", "Autres actions et parts", 0),
    ("2840", "Valeur d'acquisition", 0),
    ("2841", "Montants non appelés", 0),
    ("2848", "Plus-values actées", 0),
    ("2849", "Réductions de valeur actées", 0),
    ("285", "Autres créances", 0),
    ("2850", "Créances en compte", 0),
    ("2851", "Effets à recevoir", 0),
    ("2852", "Titres à revenu fixe", 0),
    ("2857", "Créances douteuses", 0),
    ("2859", "Réductions de valeur actées", 0),
    ("288", "Cautionnements versés en numéraires", 0),
    ("2880", "Téléphone, télefax, télex", 0),
    ("2881", "Gaz", 0),
    ("2882", "Eau", 0),
    ("2883", "Electricité", 0),
    ("2887", "Autres cautionnements versés en numéraires", 0),
    ("290", "Créances commerciales", 0),
    ("2900", "Clients", 0),
    ("29000", "Créances en compte sur entreprises liées", 0),
    ("29001", "Sur entreprises avec lesquelles il existe un lien de participation", 0),
    ("29002", "Sur clients Belgique", 0),
    ("29003", "Sur clients C.E.E.", 0),
    ("29004", "Sur clients exportation hors C.E.E.", 0),
    ("29005", "Créances sur les coparticipants (associations momentanées)", 0),
    ("2901", "Effets à recevoir", 0),
    ("29010", "Sur entreprises liées", 0),
    ("29011", "Sur entreprises avec lesquelles il existe un lien de participation", 0),
    ("29012", "Sur clients Belgique", 0),
    ("29013", "Sur clients C.E.E.", 0),
    ("29014", "Sur clients exportation hors C.E.E.", 0),
    ("2905", "Retenues sur garanties", 0),
    ("2906", "Acomptes versés", 0),
    ("2907", "Créances douteuses (à ventiler comme clients 2900)", 0),
    ("2909", "Réductions de valeur actées (à ventiler comme clients 2900)", 0),
    ("291", "Autres créances", 0),
    ("2910", "Créances en compte", 0),
    ("29100", "Sur entreprises liées", 0),
    ("29101", "Sur entreprises avec lesquelles il existe un lien de participation", 0),
    ("29102", "Sur autres débiteurs", 0),
    ("2911", "Effets à recevoir", 0),
    ("29110", "Sur entreprises liées", 0),
    ("29111", "Sur entreprises avec lesquelles il existe un lien de participation", 0),
    ("29112", "Sur autres débiteurs", 0),
    ("2912", "Créances résultant de la cession d'immobilisations données en leasing", 0),
    ("2917", "Créances douteuses", 0),
    ("2919", "Réductions de valeur actées", 0),
    ("300", "Matières premières - valeur d'acquisition", 0),
    ("309", "Matières premières - réductions de valeur actées", 0),
    ("310", "Fournitures - valeur d'acquisition", 0),
    ("3100", "matières d'approvisionnement", 0),
    ("3101", "énergie (Charbon, coke, Mazout, essence, propane, ...)", 0),
    ("3102", "produits d'entretien", 0),
    ("3103", "Fournitures diverses et petit outillage", 0),
    ("3104", "Imprimés et fournitures de bureau", 0),
    ("3105", "Fournitures de services sociaux", 0),
    ("3106", "Emballages commerciaux", 0),
    ("31060", "Emballages perdus", 0),
    ("31061", "Emballages récupérables", 0),
    ("319", "Fournitures - Réductions de valeur actées", 0),
    ("320", "Fabrication - valeur d'acquisition", 0),
    ("3200", "Produits semi-ouvrés", 0),
    ("3201", "Produits en cours de fabrication", 0),
    ("3202", "Travaux en cours", 0),
    ("3205", "Déchets", 0),
    ("3206", "Rebuts", 0),
    ("3209", "Travaux en association momentanée", 0),
    ("329", "Fabrication - réductions de valeur actées", 0),
    ("330", "Produits finis -valeur d'acquisition", 0),
    ("3300", "Produits finis", 0),
    ("3301", "Sous-produits", 0),
    ("339", "Produits finisRéductions de valeur actées", 0),
    ("340", "Marchandises - valeur d'acquisition", 0),
    ("349", "Marchandises - Réductions de valeur actées", 0),
    ("350", "Immeubles - valeur d'acquisition", 0),
    ("351", "Immeubles construits en vue de leur revente", 0),
    ("359", "Immeubles - Réductions de valeurs actées", 0),
    ("360", "Acomptes versés (à ventiler éventuellement par catégorie)", 0),
    ("369", "Achats pour stocks - réductions de valeur actées", 0),
    ("370", "Commandes - valeur d'acquisition", 0),
    ("371", "Commandes - Bénéfice pris en compte", 0),
    ("379", "Commandes - Réductions de valeur actées", 0),
    ("400", "Clients", 0),
    ("4000", "Clients belges", 0),
    ("4001", "Clients CEE", 0),
    ("4002", "Clients hors CEE", 0),
    ("4007", "Rabais, remises, ristournes à accorder et autres notes de crédit à établir", 0),
    ("4008", "Créances résultant de livraisons de biens (associations momentanées)", 0),
    ("401", "Effets à recevoir", 0),
    ("4010", "Effets à recevoir", 0),
    ("4013", "Effets à l'encaissement", 0),
    ("4015", "Effets à l'escompte", 0),
    ("402", "Clients, créances courantes, entreprises apparentées, administrateurs et gérants", 0),
    ("4020", "Entreprises liées", 0),
    ("4021", "Autres entreprises avec lesquelles il existe un lien de participation", 0),
    ("4022", "Administrateurs et gérants d'entreprise", 0),
    ("403", "Effets à recevoir sur entreprises apparentées et administrateurs et gérants", 0),
    ("4030", "Entreprises liées", 0),
    ("4031", "Autres entreprises avec lesquelles il existe un lien de participation", 0),
    ("4032", "Administrateurs et gérants de l'entreprise", 0),
    ("404", "Produits à recevoir (factures à établir)", 0),
    ("405", "Clients : retenues sur garanties", 0),
    ("406", "Acomptes versés", 0),
    ("407", "Créances douteuses", 0),
    ("408", "Compensation clients", 0),
    ("409", "Réductions de valeur actées", 0),
    ("410", "Capital appelé, non versé", 0),
    ("4100", "Appels de fonds", 0),
    ("4101", "Actionnaires défaillants", 0),
    ("411", "T.V.A. à récupérer", 1),
    ("4110", "T.V.A. due", 1),
    ("4111", "T.V.A. déductible", 1),
    ("4112", "Compte courant administration T.V.A.", 1),
    ("4118", "Taxe d'égalisation due", 1),
    ("412", "Impôts et versements fiscaux à récupérer", 1),
    ("4120", "à 4124 - Impôts belges sur le résultat", 1),
    ("4125", "à 4127 - Autres impôts belges", 1),
    ("4128", "Impôts étrangers", 1),
    ("414", "Produits à recevoir", 1),
    ("416", "Créances diverses", 1),
    ("4160", "Associés (compte d'apport en société)", 1),
    ("4161", "Avances et prêts au personnel", 1),
    ("4162", "Compte courant des associés en S.P.R.L.", 1),
    ("4163", "Compte courant des administrateurs et gérants", 1),
    ("4164", "Créances sur sociétés apparentées", 1),
    ("4166", "Emballages et matériel à rendre", 1),
    ("4167", "Etat et établissements publics", 1),
    ("41670", "Subsides à recevoir", 1),
    ("41671", "Autres créances", 1),
    ("4168", "Rabais, ristournes, remises à obtenir et autres avoirs non encore reçus", 1),
    ("417", "Créances douteuses", 1),
    ("418", "Cautionnements versés en numéraires", 1),
    ("419", "Réductions de valeur actées", 1),
    ("420", "Emprunts subordonnés", 1),
    ("4200", "Convertibles", 1),
    ("4201", "Non convertibles", 1),
    ("421", "Emprunts obligataires non subordonnés", 1),
    ("4210", "Convertibles", 1),
    ("4211", "Non convertibles", 1),
    ("422", "Dettes de location-financement et assimilées", 1),
    ("4220", "Financement de biens immobiliers", 1),
    ("4221", "Financement de biens mobiliers", 1),
    ("423", "Etablissements de crédit", 1),
    ("4230", "Dettes en compte", 1),
    ("4231", "Promesses", 1),
    ("4232", "Crédits d'acceptation", 1),
    ("424", "Autres emprunts", 1),
    ("425", "Dettes commerciales", 1),
    ("4250", "Fournisseurs", 1),
    ("4251", "Effets à payer", 1),
    ("426", "Cautionnements reçus en numéraires", 1),
    ("429", "Dettes diverses", 1),
    ("4290", "Entreprises liées", 1),
    ("4291", "Entreprises avec lesquelles il existe un lien de participation", 1),
    ("4292", "Administrateurs, gérants, associés", 1),
    ("4299", "Autres dettes", 1),
    ("430", "Etablissements de crédit. Emprunts en compte à terme fixe", 1),
    ("431", "Etablissements de crédit. Promesses", 1),
    ("432", "Etablissements de crédit. Crédits d'acceptation", 1),
    ("433", "Etablissements de crédit. Dettes en compte courant", 1),
    ("439", "Autres emprunts", 1),
    ("440", "Fournisseurs", 1),
    ("4400", "Entreprises apparentées", 1),
    ("44000", "Entreprises liées", 1),
    ("44001", "Entreprises avec lesquelles il existe un lien de participation", 1),
    ("4401", "Fournisseurs ordinaires", 1),
    ("44010", "Fournisseurs belges", 1),
    ("44011", "Fournisseurs CEE", 1),
    ("44012", "Fournisseurs importation", 1),
    ("4402", "Dettes envers les coparticipants (associations momentanées)", 1),
    ("4403", "Fournisseurs - retenues de garanties", 1),
    ("441", "Effets à payer", 1),
    ("4410", "Entreprises apparentées", 1),
    ("44100", "Entreprises liées", 1),
    ("44101", "Entreprises avec lesquelles il existe un lien de participation", 1),
    ("4411", "Fournisseurs ordinaires", 1),
    ("44110", "Fournisseurs belges", 1),
    ("44111", "Fournisseurs CEE", 1),
    ("44112", "Fournisseurs importation", 1),
    ("444", "Factures à recevoir", 1),
    ("446", "Acomptes reçus", 1),
    ("448", "Compensations fournisseurs", 1),
    ("450", "Dettes fiscales estimées", 1),
    ("4501", "à 4504 - Impôts sur le résultat", 1),
    ("4505", "à 4507 - Autres impôts en Belgique", 1),
    ("4508", "Impôts à l'étranger", 1),
    ("451", "T.V.A. à payer", 1),
    ("4510", "T.V.A. due", 1),
    ("4511", "T.V.A. déductible", 1),
    ("4512", "Compte courant administration T.V.A.", 1),
    ("4518", "Taxe d'égalisation due", 1),
    ("452", "Impôts et taxes à payer", 1),
    ("45250", "Précompte immobilier", 1),
    ("45251", "Impôts communaux à payer", 1),
    ("45252", "Impôts provinciaux à payer", 1),
    ("45253", "Autres impôts et taxes à payer", 1),
    ("4528", "Impôts et taxes à l'étranger", 1),
    ("453", "Précomptes retenus", 1),
    ("4530", "Précompte professionnel retenu sur rémunérations", 1),
    ("4531", "Précompte professionnel retenu sur tantièmes", 1),
    ("4532", "Précompte mobilier retenu sur dividendes attribués", 1),
    ("4533", "Précompte mobilier retenu sur intérêts payés", 1),
    ("4538", "Autres précomptes retenus", 1),
    ("454", "Office National de la Sécurité Sociale", 1),
    ("4540", "Arriérés", 1),
    ("4541", "1er trimestre", 1),
    ("4542", "2ème trimestre", 1),
    ("4543", "3ème trimestre", 1),
    ("4544", "4ème trimestre", 1),
    ("455", "Rémunérations", 1),
    ("4550", "Administrateurs, gérants et commissaires (non réviseurs)", 1),
    ("4551", "Direction", 1),
    ("4552", "Employés", 1),
    ("4553", "Ouvriers", 1),
    ("456", "Pécules de vacances", 1),
    ("4560", "Direction", 1),
    ("4561", "Employés", 1),
    ("4562", "Ouvriers", 1),
    ("459", "Autres dettes sociales", 1),
    ("4590", "Provision pour gratifications de fin d'année", 1),
    ("4591", "Départs de personnel", 1),
    ("4592", "Oppositions sur rémunérations", 1),
    ("4593", "Assurances relatives au personnel", 1),
    ("45930", "Assurance loi", 1),
    ("45931", "Assurance salaire garanti", 1),
    ("45932", "Assurance groupe", 1),
    ("45933", "Assurances individuelles", 1),
    ("4594", "Caisse d'assurances sociales pour travailleurs indépendants", 1),
    ("4597", "Dettes et provisions sociales diverses", 1),
    ("46", "Acomptes reçus sur commandes", 1),
    ("470", "Dividendes et tantièmes d'exercices antérieurs", 0),
    ("471", "Dividendes de l'exercice", 0),
    ("472", "Tantièmes de l'exercice", 0),
    ("473", "Autres allocataires", 0),
    ("480", "Obligations et coupons échus", 1),
    ("481", "Actionnaires - capital à rembourser", 1),
    ("482", "Participation du personnel à payer", 1),
    ("483", "Acomptes reçus d'autres tiers à moins d'un an", 1),
    ("486", "Emballages et matériel consignés", 1),
    ("488", "Cautionnements reçus en numéraires", 1),
    ("489", "Autres dettes diverses", 1),
    ("490", "Charges à reporter (à subdiviser par catégorie de charges)", 1),
    ("491", "Produits acquis", 1),
    ("4910", "Produits d'exploitation", 1),
    ("49100", "Ristournes, rabais à obtenir", 1),
    ("49101", "Commissions à obtenir", 1),
    ("49102", "Autres produits d'exploitation (redevances par exemple)", 1),
    ("4911", "Produits financiers", 1),
    ("49110", "Intérêts courus et non échus sur prêts et débits", 1),
    ("49111", "Autres produits financiers", 1),
    ("492", "Charges à imputer (à subdiviser par catégorie de charges)", 1),
    ("493", "Produits à reporter", 1),
    ("4930", "Produits d'exploitation à reporter", 1),
    ("4931", "Produits financiers à reporter", 1),
    ("499", "Comptes d'attente", 1),
    ("4990", "Compte d'attente", 1),
    ("4991", "Compte de répartition périodique des charges", 1),
    ("4999", "Transferts d'exercice", 1),
    ("550", "ACTIONS PROPRES", 0),
    ("5510", "Actions - Valeur d'acquisition", 0),
    ("5511", "Actions - Montants non appelés", 0),
    ("5519", "Actions - Réductions de valeur actées", 0),
    ("5520", "Titres - Valeur d'acquisition", 0),
    ("5529", "Titres - Réductions de valeur actées", 0),
    ("5530", "Dépôts à terme - De plus d'un an", 0),
    ("5531", "Dépôts à terme - De plus d'un mois et à un an au plus", 0),
    ("5532", "Dépôts à terme - D'un mois au plus", 0),
    ("5539", "Dépôts à terme - Réductions de valeur actées", 0),
    ("54", "Valeurs échues à l'encaissement", 0),
    ("5540", "Chèques à encaisser", 0),
    ("5541", "Coupons à encaisser", 0),
    ("55", "Etablissemnts de crédit", 0),
    ("5500", "Etablissemnts de crédit - Comptes courants", 0),
    ("5501", "Etablissemnts de crédit - Chèques émis", 0),
    ("5509", "Etablissemnts de crédit - Réductions de valeur actées", 0),
    ("5510", "Etablissemnts de crédit - Comptes courants", 0),
    ("5511", "Etablissemnts de crédit - Chèques émis", 0),
    ("5519", "Etablissemnts de crédit - Réductions de valeur actées", 0),
    ("5520", "Etablissemnts de crédit - Comptes courants", 0),
    ("5521", "Etablissemnts de crédit - Chèques émis", 0),
    ("5529", "Etablissemnts de crédit - Réductions de valeur actées", 0),
    ("5530", "Etablissemnts de crédit - Comptes courants", 0),
    ("5531", "Etablissemnts de crédit - Chèques émis", 0),
    ("5539", "Etablissemnts de crédit - Réductions de valeur actées", 0),
    ("5540", "Etablissemnts de crédit - Comptes courants", 0),
    ("5541", "Etablissemnts de crédit - Chèques émis", 0),
    ("5549", "Etablissemnts de crédit - Réductions de valeur actées", 0),
    ("5550", "Etablissemnts de crédit - Comptes courants", 0),
    ("5551", "Etablissemnts de crédit - Chèques émis", 0),
    ("5559", "Etablissemnts de crédit - Réductions de valeur actées", 0),
    ("5560", "Etablissemnts de crédit - Comptes courants", 0),
    ("5561", "Etablissemnts de crédit - Chèques émis", 0),
    ("5569", "Etablissemnts de crédit - Réductions de valeur actées", 0),
    ("5570", "Etablissemnts de crédit - Comptes courants", 0),
    ("5571", "Etablissemnts de crédit - Chèques émis", 0),
    ("5579", "Etablissemnts de crédit - Réductions de valeur actées", 0),
    ("5580", "Etablissemnts de crédit - Comptes courants", 0),
    ("5581", "Etablissemnts de crédit - Chèques émis", 0),
    ("5589", "Etablissemnts de crédit - Réductions de valeur actées", 0),
    ("5590", "Etablissemnts de crédit - Comptes courants", 0),
    ("5591", "Etablissemnts de crédit - Chèques émis", 0),
    ("5599", "Etablissemnts de crédit - Réductions de valeur actées", 0),
    ("560", "Chèques postaux - Compte courant", 0),
    ("561", "Chèques postaux - Chèques émis", 0),
    ("570", "Caisses - espèces - centrale", 0),
    ("577", "Caisses - espèces - succursales et agences)", 0),
    ("578", "Caisses - timbres", 0),
    ("58", "VIREMENTS INTERNES", 0),
    ("600", "Achats de matières premières", 4),
    ("601", "Achats de fournitures", 4),
    ("602", "Achats de services, travaux et études", 4),
    ("603", "Sous-traitances générales", 4),
    ("604", "Achats de marchandises", 4),
    ("605", "Achats d'immeubles destinés à la revente", 4),
    ("608", "Remises, ristournes et rabais obtenus sur achats", 4),
    ("609", "Variations de stocks", 4),
    ("6090", "De matières premières", 4),
    ("6091", "De fournitures", 4),
    ("6094", "De marchandises", 4),
    ("6095", "D'immeubles destinés à la vente", 4),
    ("61", "Services et biens diver", 4),
    ("610", "Loyers et charges locatives", 4),
    ("6100", "Loyers divers", 4),
    ("6101", "Charges locatives (assurances, frais de confort, ...)", 4),
    ("611", "Entretien et réparation (fournitures et prestations)", 4),
    ("612", "Fournitures faites à l'entreprise", 4),
    ("6120", "Eau, gaz, électricité, vapeur", 4),
    ("61200", "Eau", 4),
    ("61201", "Gaz", 4),
    ("61202", "Electricité", 4),
    ("61203", "Vapeur", 4),
    ("6121", "Téléphone, télégrammes, télex, téléfax, frais postaux", 4),
    ("61210", "Téléphone", 4),
    ("61211", "Télégrammes", 4),
    ("61212", "Télex et téléfax", 4),
    ("61213", "Frais postaux", 4),
    ("6122", "Livres, bibliothèque", 4),
    ("6123", "Imprimés et fournitures de bureau (si non comptabilisé au 601)", 4),
    ("613", "Rétributions de tiers", 4),
    ("6130", "Redevances et royalties", 4),
    ("61300", "Redevances pour brevets, licences, marques, accessoires", 4),
    ("61301", "Autres redevances (procédés de fabrication)", 4),
    ("6131", "Assurances non relatives au personnel", 4),
    ("61310", "Assurance incendie", 4),
    ("61311", "Assurance vol", 4),
    ("61312", "Assurance autos", 4),
    ("61313", "Assurance crédit", 4),
    ("61314", "Assurances frais généraux", 4),
    ("6132", "Divers", 4),
    ("61320", "Commissions aux tiers", 4),
    ("61321", "Honoraires d'avocats, d'experts, etc ...", 4),
    ("61322", "Cotisations aux groupements professionnels", 4),
    ("61323", "Dons, libéralités, ...", 4),
    ("61324", "Frais de contentieux", 4),
    ("61325", "Publications légales", 4),
    ("6133", "Transports et déplacements", 4),
    ("61330", "Transports de personnel", 4),
    ("61331", "Voyages, déplacements, représentations", 4),
    ("6134", "Personnel intérimaire", 4),
    ("614", "Annonces, publicité, propagande et documentation", 4),
    ("6140", "Annonces et insertions", 4),
    ("6141", "Catalogues et imprimés", 4),
    ("6142", "Echantillons", 4),
    ("6143", "Foires et expositions", 4),
    ("6144", "Primes", 4),
    ("6145", "Cadeaux à la clientèle", 4),
    ("6146", "Missions et réceptions", 4),
    ("6147", "Documentation", 4),
    ("615", "Sous-traitants", 4),
    ("6150", "Sous-traitants pour activités propres", 4),
    ("6151", "Sous-traitants d'associations momentanées (coparticipants)", 4),
    ("6152", "Quote-part bénéficiaire des coparticipants", 4),
    ("61700", "Personnel intérimaire et personnes mises à la disposition de l'entreprise", 4),
    ("61800", "Rémunérations, primes pour assurances extralégales, pensions de retraite et de survie des administrateurs, gérants et associés actifs qui ne sont pas attribuées en vertu d'un contrat de travail", 4),
    ("620", "Rémunérations et avantages sociaux directs", 4),
    ("6200", "Administrateurs ou gérants", 4),
    ("6201", "Personnel de direction", 4),
    ("6202", "Employés", 4),
    ("6203", "Ouvriers", 4),
    ("6204", "Autres membres du personnel", 4),
    ("621", "Cotisations patronales d'assurances sociales", 4),
    ("6210", "Sur salaires", 4),
    ("6211", "Sur appointements et commissions", 4),
    ("622", "Primes patronales pour assurances extralégales", 4),
    ("623", "Autres frais de personnel", 4),
    ("6230", "Assurances du personnel", 4),
    ("62300", "Assurances loi, responsabilité civile, chemin du travail", 4),
    ("62301", "Assurance salaire garanti", 4),
    ("62302", "Assurances individuelles", 4),
    ("6231", "Charges sociales diverses", 4),
    ("62310", "Jours fériés payés", 4),
    ("62311", "Salaire hebdomadaire garanti", 4),
    ("62312", "Allocations familiales complémentaires", 4),
    ("6232", "Charges sociales des administrateurs, gérants et commissaires", 4),
    ("62320", "Allocations familiales complémentaires pour non salariés", 4),
    ("62321", "Lois sociales pour indépendants", 4),
    ("62322", "Divers", 4),
    ("624", "Pensions de retraite et de survie", 4),
    ("6240", "Administrateurs et gérants", 4),
    ("6241", "Personnel", 4),
    ("625", "Provision pour pécule de vacances", 4),
    ("6250", "Dotations", 4),
    ("6251", "Utilisations et reprises", 4),
    ("630", "Dotations aux amortissements et aux réductions de valeur sur immobilisations", 4),
    ("6300", "Dotations aux amortissements sur frais d'établissement", 4),
    ("6301", "Dotations aux amortissements sur immobilisations incorporelles", 4),
    ("6302", "Dotations aux amortissements sur immobilisations corporelles", 4),
    ("6308", "Dotations aux réductions de valeur sur immobilisations incorporelles", 4),
    ("6309", "Dotations aux réductions de valeur sur immobilisations corporelles", 4),
    ("631", "Réductions de valeur sur stocks", 4),
    ("6310", "Dotations", 4),
    ("6311", "Reprises", 4),
    ("632", "Réductions de valeur sur commandes en cours d'exécution", 4),
    ("6320", "Dotations", 4),
    ("6321", "Reprises", 4),
    ("633", "Réductions de valeur sur créances commerciales à plus d'un an", 4),
    ("6330", "Dotations", 4),
    ("6331", "Reprises", 4),
    ("634", "Réductions de valeur sur créances commerciales à un an au plus", 4),
    ("6340", "Dotations", 4),
    ("6341", "Reprises", 4),
    ("635", "Provisions pour pensions et obligations similaires", 4),
    ("6350", "Dotations", 4),
    ("6351", "Utilisations et reprises", 4),
    ("636", "Provisions pour grosses réparations et gros entretiens", 4),
    ("6360", "Dotations", 4),
    ("6361", "Utilisations et reprises", 4),
    ("637", "Provisions pour autres risques et charges", 4),
    ("6370", "Dotations", 4),
    ("6371", "Utilisations et reprises", 4),
    ("640", "Charges fiscales d'exploitation", 4),
    ("6400", "Taxes et impôts directs", 4),
    ("64000", "Taxes sur autos et camions", 4),
    ("6401", "Taxes et impôts indirects", 4),
    ("64010", "Timbres fiscaux pris en charge par la firme", 4),
    ("664011", "Droits d'enregistrement", 4),
    ("64012", "T.V.A. non déductible", 4),
    ("6402", "Impôts provinciaux et communaux", 4),
    ("64020", "Taxe sur la force motrice", 4),
    ("64021", "Taxe sur le personnel occupé", 4),
    ("6403", "Taxes diverses", 4),
    ("641", "Moins-values sur réalisations courantes d'immobilisations corporelles", 4),
    ("642", "Moins-values sur réalisations de créances commerciales", 4),
    ("643", "Charges d'exploitations diverses", 4),
    ("644", "Charges d'exploitations diverses", 4),
    ("645", "Charges d'exploitations diverses", 4),
    ("646", "Charges d'exploitations diverses", 4),
    ("647", "Charges d'exploitations diverses", 4),
    ("648", "Charges d'exploitations diverses", 4),
    ("649", "Charges d'exploitation portées à l'actif au titre de restructuration", 4),
    ("650", "Charges des dettes", 4),
    ("6500", "Intérêts, commissions et frais afférents aux dettes", 4),
    ("6501", "Amortissements des agios et frais d'émission d'emprunts", 4),
    ("6502", "Autres charges de dettes", 4),
    ("6503", "Intérêts intercalaires portés à l'actif", 4),
    ("651", "Réductions de valeur sur actifs circulants", 4),
    ("6510", "Dotations", 4),
    ("6511", "Reprises", 4),
    ("652", "Moins-values sur réalisation d'actifs circulants", 4),
    ("653", "Charges d'escompte de créances", 4),
    ("654", "Différences de change", 4),
    ("655", "Ecarts de conversion des devises", 4),
    ("656", "Frais de banques, de chèques postaux", 4),
    ("657", "Commissions sur ouvertures de crédit, cautions, avals", 4),
    ("658", "Frais de vente des titres", 4),
    ("660", "Amortissements et réductions de valeur exceptionnels", 4),
    ("6600", "Sur frais d'établissement", 4),
    ("6601", "Sur immobilisations incorporelles", 4),
    ("6602", "Sur immobilisations corporelles", 4),
    ("661", "Réductions de valeur sur immobilisations financières", 4),
    ("662", "Provisions pour risques et charges exceptionnels", 4),
    ("663", "Moins-values sur réalisation d'actifs immobilisés", 4),
    ("6630", "Sur immobilisations incorporelles", 4),
    ("6631", "Sur immobilisations corporelles", 4),
    ("6632", "Sur immobilisations détenues en location-financement et droits similaires", 4),
    ("6633", "Sur immobilisations financières", 4),
    ("6634", "Sur immeubles acquis ou construits en vue de la revente", 4),
    ("664", "Pénalités et amendes diverses", 4),
    ("665", "Différence de charge", 4),
    ("668", "Autres charges exceptionnelles", 4),
    ("669", "Charges exceptionnelles transférées à l'actif en frais de restructuration", 4),
    ("670", "Impôts belges sur le résultat de l'exercice", 4),
    ("6700", "Impôts et précomptes dus ou versés", 4),
    ("6701", "Excédent de versements d'impôts et précomptes porté à l'actif", 4),
    ("6702", "Charges fiscales estimées", 4),
    ("671", "Impôts belges sur le résultat d'exercices antérieurs", 4),
    ("6710", "Suppléments d'impôts dus ou versés", 4),
    ("6711", "Suppléments d'impôts estimés", 4),
    ("6712", "Provisions fiscales constituées", 4),
    ("672", "Impôts étrangers sur le résultat de l'exercice", 4),
    ("673", "Impôts étrangers sur le résultat d'exercices antérieurs", 4),
    ("690", "Perte reportée de l'exercice précédent", 4),
    ("691", "Dotation à la réserve légale", 4),
    ("692", "Dotation aux autres réserves", 4),
    ("693", "Bénéfice à reporter", 4),
    ("694", "Rémunération du capital", 4),
    ("695", "Administrateurs ou gérants", 4),
    ("696", "Autres allocataires", 4),
    ("700", "Ventes de marchandises", 3),
    ("7000", "Ventes en Belgique", 3),
    ("7001", "Ventes dans les pays membres de la C.E .E.", 3),
    ("7002", "Ventes à l'exportation", 3),
    ("701", "Ventes de produits finis", 3),
    ("7010", "Ventes en Belgique", 3),
    ("7011", "Ventes dans les pays membres de la C.E .E.", 3),
    ("7012", "Ventes à l'exportation", 3),
    ("702", "Ventes de déchets et rebuts", 3),
    ("7020", "Ventes en Belgique", 3),
    ("7021", "Ventes dans les pays membres de la C.E .E.", 3),
    ("7022", "Ventes à l'exportation", 3),
    ("703", "Ventes d'emballages récupérables", 3),
    ("704", "Facturations des travaux en cours (associations momentanées)", 3),
    ("705", "Prestations de services", 3),
    ("7050", "Prestations de services en Belgique", 3),
    ("7051", "Prestations de services dans les pays membres de la C.E .E.", 3),
    ("7052", "Prestations de services en vue de l'exportation", 3),
    ("706", "Pénalités et dédits obtenus par l'entreprise", 3),
    ("707", "Ventes et prestations de services", 3),
    ("708", "Remises, ristournes et rabais accordés", 3),
    ("7080", "Sur ventes de marchandises", 3),
    ("7081", "Sur ventes de produits finis", 3),
    ("7082", "Sur ventes de déchets et rebuts", 3),
    ("7083", "Sur prestations de services", 3),
    ("7084", "Mali sur travaux facturés aux associations momentanées", 3),
    ("712", "Des en cours de fabrication", 3),
    ("713", "Des produits finis", 3),
    ("715", "Des immeubles construits destinés à la vente", 3),
    ("717", "Des commandes en cours d'exécution", 3),
    ("7170", "Commandes en cours - Coût de revient", 3),
    ("71700", "Coût des commandes en cours d'exécution", 3),
    ("71701", "Coût des travaux en cours des associations momentanées", 3),
    ("7171", "Bénéfices portés en compte sur commandes en cours", 3),
    ("71710", "Sur commandes en cours d'exécution", 3),
    ("71711", "Sur travaux en cours des associations momentanées", 3),
    ("720", "En frais d'établissement", 3),
    ("721", "En immobilisations incorporelles", 3),
    ("722", "En immobilisations corporelles", 3),
    ("723", "En immobilisations en cours", 3),
    ("740", "Subsides d'exploitation et montants compensatoires", 3),
    ("73", "Cotisations, dons, legs et subsides", 3),
    ("741", "Plus-values sur réalisations courantes d'immobilisations corporelles", 3),
    ("742", "Plus-values sur réalisations de créances commerciales", 3),
    ("743", "Produits de services exploités dans l'intérêt du personnel", 3),
    ("744", "Commissions et courtages", 3),
    ("745", "Redevances pour brevets et licences", 3),
    ("746", "Prestations de services (transports, études , etc...)", 3),
    ("747", "Revenus des immeubles affectés aux activités non professionnelles", 3),
    ("748", "Locations diverses à caractère professionnel", 3),
    ("749", "Produits divers", 3),
    ("7490", "Bonis sur reprises d'emballages consignés", 3),
    ("7491", "Bonis sur travaux en associations momentanées", 3),
    ("750", "Produits des immobilisations financières", 3),
    ("7500", "Revenus des actions", 3),
    ("7501", "Revenus des obligations", 3),
    ("7502", "Revenus des créances à plus d'un an", 3),
    ("751", "Produits des actifs circulants", 3),
    ("752", "Plus-values sur réalisations d'actifs circulants", 3),
    ("753", "Subsides en capital et en intérêts", 3),
    ("754", "Différences de change", 3),
    ("755", "Ecarts de conversion des devises", 3),
    ("756", "Produits des autres créances", 3),
    ("757", "Escomptes obtenus", 3),
    ("758", "Produits financiers divers", 3),
    ("759", "Produits financiers divers", 3),
    ("760", "Reprises d'amortissements et de réductions de valeur", 3),
    ("7600", "Sur immobilisations incorporelles", 3),
    ("7601", "Sur immobilisations corporelles", 3),
    ("761", "Reprises de réductions de valeur sur immobilisations financières", 3),
    ("762", "Reprises de provisions pour risques et charges exceptionnelles", 3),
    ("763", "Plus-values sur réalisation d'actifs immobilisés", 3),
    ("7630", "Sur immobilisations incorporelles", 3),
    ("7631", "Sur immobilisations corporelles", 3),
    ("7632", "Sur immobilisations financières", 3),
    ("764", "Autres produits exceptionnels", 3),
    ("771", "Impôts belges sur le résultat", 3),
    ("7710", "Régularisations d'impôts dus ou versés", 3),
    ("7711", "Régularisations d'impôts estimés", 3),
    ("7712", "Reprises de provisions fiscales", 3),
    ("773", "Impôts étrangers sur le résultat", 3),
    ("790", "Bénéfice reporté de l'exercice précédent", 3),
    ("791", "Prélèvement sur le capital et les primes d'émission", 3),
    ("792", "Prélèvement sur les réserves", 3),
    ("793", "Perte à reporter", 3),
    ("794", "Intervention d'associés (ou du propriétaire) dans la perte", 3)]


def find_charts(code):
    current_charts = None
    for chart_item in GENERAL_CHARTS_ACCOUNT:
        if code[:len(chart_item[0])] == chart_item[0]:
            current_charts = chart_item
        elif current_charts is not None:
            break
    return current_charts


class BelgiumSystemAcounting(DefaultSystemAccounting):

    NEGATIF_ACCOUNT = "141"
    POSITIF_ACCOUNT = "140"

    def has_minium_code_size(self):
        return False

    def get_general_mask(self):
        return GENERAL_MASK

    def get_cash_mask(self):
        return CASH_MASK

    def get_cash_begin(self):
        return CASH_MASK_BEGIN

    def get_provider_mask(self):
        return PROVIDER_MASK

    def get_customer_mask(self):
        return CUSTOMER_MASK

    def get_employed_mask(self):
        return EMPLOYED_MASK

    def get_societary_mask(self):
        return SOCIETARY_MASK

    def get_third_mask(self):
        return THIRD_MASK

    def get_revenue_mask(self):
        return REVENUE_MASK

    def get_expence_mask(self):
        return EXPENSE_MASK

    def get_annexe_mask(self):
        return r'X'

    def new_charts_account(self, code):
        code = code.strip()
        if code == '':
            return '', -1
        pattern = re.compile(GENERAL_MASK)
        if pattern.match(code):
            current_charts = find_charts(code)
            if current_charts is not None:
                return current_charts[1], current_charts[2]
        return '', -2

    def get_export_xmlfiles(self):
        return None
